Simple test
------------

For I2C or SPI communications, ensure your device works with this simple test.

.. literalinclude:: ../examples/l3gd20_simpletest.py
    :caption: examples/l3gd20_simpletest.py
    :linenos:
